LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.numeric_std.ALL;

LIBRARY topic;
USE topic.topic_pkg.ALL;

USE std.env.ALL;

ENTITY pwm_fan_controller_tb IS
END ENTITY;

ARCHITECTURE behavioral OF pwm_fan_controller_tb IS

   SIGNAL n_clk           : std_logic := '0';
   SIGNAL n_rst           : std_logic := '1';
   SIGNAL n_fan_enable    : std_logic;
   SIGNAL n_fan_req_speed : std_logic_vector(7 DOWNTO 0);
   SIGNAL n_fan_act_speed : std_logic_vector(31 DOWNTO 0);
   SIGNAL n_fan_pwm       : std_logic;
   SIGNAL n_fan_tacho     : std_logic;
   SIGNAL n_fan_error     : std_logic;

BEGIN

   -- Clock generation
   n_clk <= NOT n_clk AFTER 10 ns;

   ResetProc : PROCESS
   BEGIN
      n_rst <= '1';
      WAIT FOR 50 ns;
      WAIT UNTIL rising_edge(n_clk);
      n_rst <= '0';

      WAIT;
   END PROCESS;

   stim : PROCESS
   BEGIN
      WAIT UNTIL n_rst = '0';

      WAIT UNTIL rising_edge(n_clk);

      n_fan_req_speed <= std_logic_vector(to_unsigned(200, 8));

      WAIT UNTIL rising_edge(n_clk);

      n_fan_enable <= '1';

      WAIT FOR 250 ms;

      n_fan_req_speed <= std_logic_vector(to_unsigned(150, 8));

      WAIT FOR 250 ms;

      n_fan_req_speed <= std_logic_vector(to_unsigned(255, 8));

      WAIT FOR 250 ms;

      n_fan_req_speed <= std_logic_vector(to_unsigned(25, 8));

      WAIT FOR 250 ms;

      ASSERT (n_fan_req_speed /= (n_fan_req_speed'RANGE => '0'))
      REPORT "n_fan_req_speed should have a value other than 0 by now." SEVERITY failure;

      n_fan_enable <= '0';

      WAIT FOR 100 ms;
      WAIT UNTIL rising_edge(n_clk);

      finish(0);

   END PROCESS;

   tacho_create : PROCESS(n_clk)
   BEGIN
      IF (rising_edge(n_clk)) THEN
         n_fan_tacho <= n_fan_pwm;
      END IF;
   END PROCESS;

   fan_controller_i : pwm_fan_controller
      GENERIC MAP(
         p_clkin_freq            => 100_000_000,
         p_pwm_freq              => 30,
         p_pwm_precision         => 255,
         p_pulse_stretch_timeout => 100_000_000
      )
      PORT MAP(
         i_clk           => n_clk,
         i_rst           => n_rst,
         i_fan_enable    => n_fan_enable,
         i_fan_req_speed => n_fan_req_speed,
         o_fan_act_speed => n_fan_act_speed,
         o_fan_pwm       => n_fan_pwm,
         i_fan_tacho     => n_fan_tacho,
         o_fan_error     => n_fan_error
      );


END behavioral;
